@@ -1,8 +1,6 @@
 test_that("it should read options_open_interest_read", {
-  if (!covr::in_covr()) {
-    skip_on_cran()
-    skip_if_offline()
-  }
+  skip_on_cran()
+  skip_if_offline()
 
   f <- system.file("extdata/big-files/OpcoesAcoesEmAberto.zip",
     package = "rb3"
@@ -59,4 +57,4 @@ test_that("it should read company_cash_dividends_reader", {
   f <- copy_file_to_temp(f)
   df <- suppressWarnings(read_marketdata(f, "GetListedCashDividends"))
   expect_s3_class(df, "data.frame")
-})
\ No newline at end of file
+})
